@@ -12,7 +12,7 @@ class Factory(object):
 
 	def createValueObject(self, name = None, unit = None, quantity = None, description = None, datatype = None):
 		from SeasObjects.model.ValueObject import ValueObject
-		from SeasObjects.model.Variant import Variant
+		from SeasObjects.rdf.Variant import Variant
 
 		vo = None
 		try:
