@@ -24,14 +24,14 @@ class ResponseFactory(object):
 		# timestamp of when this message is being generated (now)
 		resp.setGeneratedAt(datetime.datetime.now())
 
-		resp.addType(RESOURCE.SEAS_RESPONSE)
+		resp.addType(RESOURCE.RESPONSE)
 		
 		return resp
 
 	
 	def fromString(self, data, serialization):
 		try :
-			return Response().parse(Tools().getResourceByType(RESOURCE.SEAS_RESPONSE, Tools().fromString(data, serialization)));
+			return Response().parse(Tools().getResourceByType(RESOURCE.RESPONSE, Tools().fromString(data, serialization)));
 		except:
 			print "Unable to parse Response by type seas:Response from the given string."
 			traceback.print_exc()
