@@ -10,7 +10,7 @@ class AliveRequest(Request):
 	
 	def __init__(self, uri = None):
 		Request.__init__(self, uri)
-		self.setType(RESOURCE.SEAS_ALIVEREQUEST)
+		self.setType(RESOURCE.ALIVEREQUEST)
 	
 	def serialize(self, model):
 		request = super(AliveRequest, self).serialize(model)
@@ -37,6 +37,6 @@ class AliveRequest(Request):
 
 	def fromString(self, data, serialization):
 		m = Tools().fromString(data, serialization)
-		res = Tools().getResourceByType(RESOURCE.SEAS_ALIVEREQUEST, m)
+		res = Tools().getResourceByType(RESOURCE.ALIVEREQUEST, m)
 		return self.parse(res)
 		
\ No newline at end of file
