@@ -11,11 +11,11 @@ class AliveResponse(Response):
 	
 	def __init__(self, uri = None):
 		Response.__init__(self, uri)
-		self.setType(RESOURCE.SEAS_ALIVERESPONSE)
+		self.setType(RESOURCE.ALIVERESPONSE)
 	
 	def fromString(self, data, serialization):
 		try:
-			return AliveResponse().parse(Tools().getResourceByType(RESOURCE.SEAS_ALIVERESPONSE, Tools().fromString(data, serialization)))
+			return AliveResponse().parse(Tools().getResourceByType(RESOURCE.ALIVERESPONSE, Tools().fromString(data, serialization)))
  		except:
 			print "Unable to parse AliveResponse from the given string."
 			traceback.print_exc() 
