@@ -7,7 +7,7 @@ class Availability(Ability):
 
 	def __init__(self, uri = None):
 		Ability.__init__(self, uri)
-		self.setType(RESOURCE.SEAS_AVAILABILITY);
+		self.setType(RESOURCE.AVAILABILITY);
 		
 	def parse(self, resource):
 		if isinstance(resource, Resource):
