@@ -15,7 +15,7 @@ class Direction(Obj):
 		self.heading = None
 		self.tracking = None
 		self.course = None
-		self.setType(RESOURCE.SEAS_DIRECTION);
+		self.setType(RESOURCE.DIRECTION);
 	
 	def hasHeading(self):
 		return self.heading is not None
@@ -57,16 +57,16 @@ class Direction(Obj):
 		direction = super(Direction, self).serialize(model)
 		
 		if self.hasBearing():
-			direction.addProperty(model.createProperty( PROPERTY.SEAS_BEARING ), self.getBearing().serialize(model))
+			direction.addProperty(model.createProperty( PROPERTY.BEARING ), self.getBearing().serialize(model))
 
 		if self.hasHeading():
-			direction.addProperty(model.createProperty( PROPERTY.SEAS_HEADING ), self.getHeading().serialize(model))
+			direction.addProperty(model.createProperty( PROPERTY.HEADING ), self.getHeading().serialize(model))
 
 		if self.hasTracking():
-			direction.addProperty(model.createProperty( PROPERTY.SEAS_TRACKING ), self.getTracking().serialize(model))
+			direction.addProperty(model.createProperty( PROPERTY.TRACKING ), self.getTracking().serialize(model))
 
 		if self.hasCourse():
-			direction.addProperty(model.createProperty( PROPERTY.SEAS_COURSE ), self.getCourse().serialize(model))
+			direction.addProperty(model.createProperty( PROPERTY.COURSE ), self.getCourse().serialize(model))
 
 		return direction
 	
@@ -89,7 +89,7 @@ class Direction(Obj):
 			predicate = str(statement.getPredicate())
 	
 			# bearing
-			if predicate == PROPERTY.SEAS_BEARING:
+			if predicate == PROPERTY.BEARING:
 				try:
 					self.setBearing(ValueObject().parse(statement.getResource()))
 				except:
@@ -98,7 +98,7 @@ class Direction(Obj):
 				return
 	
 			# heading
-			if predicate == PROPERTY.SEAS_HEADING:
+			if predicate == PROPERTY.HEADING:
 				try:
 					self.setHeading(ValueObject().parse(statement.getResource()))
 				except:
@@ -107,7 +107,7 @@ class Direction(Obj):
 				return
 			
 			# tracking
-			if predicate == PROPERTY.SEAS_TRACKING:
+			if predicate == PROPERTY.TRACKING:
 				try:
 					self.setTracking(ValueObject().parse(statement.getResource()))
 				except:
@@ -116,7 +116,7 @@ class Direction(Obj):
 				return
 	
 				# tracking
-			if predicate == PROPERTY.SEAS_COURSE:
+			if predicate == PROPERTY.COURSE:
 				try:
 					self.setCourse(ValueObject().parse(statement.getResource()))
 				except:
