@@ -22,7 +22,7 @@ class Entity(Obj):
 		self.capacities = []
 		self.interfaces = []
 		self.relatedUrls = {}
-		self.setType(RESOURCE.SEAS_ENTITY)
+		self.setType(RESOURCE.ENTITY)
 
 	
 	def serialize(self, model):
@@ -30,46 +30,46 @@ class Entity(Obj):
 		
 		# zone
 		if self.hasZone():
-			entity.addProperty(model.createProperty( PROPERTY.SEAS_ZONE ), self.zone.serialize(model))
+			entity.addProperty(model.createProperty( PROPERTY.ZONE ), self.zone.serialize(model))
 		
 		# address
 		if self.hasAddress():
-			entity.addProperty(model.createProperty( PROPERTY.VCARD_HASADDRESS ), self.address.serialize(model))
+			entity.addProperty(model.createProperty( PROPERTY.HASADDRESS ), self.address.serialize(model))
 		
 		# coordinate
 		if self.hasCoordinates():
-			entity.addProperty(model.createProperty( PROPERTY.SEAS_LOCATION ), self.coordinates.serialize(model))
+			entity.addProperty(model.createProperty( PROPERTY.LOCATION ), self.coordinates.serialize(model))
 		
 		# controllability
 		for controllability in self.controllabilities:
-			entity.addProperty( model.createProperty( PROPERTY.SEAS_HASEVALUATION ), controllability.serialize(model) )
+			entity.addProperty( model.createProperty( PROPERTY.HASEVALUATION ), controllability.serialize(model) )
 
 		# availability
 		for availability in self.availabilities:
-			entity.addProperty( model.createProperty( PROPERTY.SEAS_HASAVAILABILITY ), availability.serialize(model) )
+			entity.addProperty( model.createProperty( PROPERTY.HASAVAILABILITY ), availability.serialize(model) )
 
 		# data availability
 		for availability in self.dataAvailabilities:
-			entity.addProperty( model.createProperty( PROPERTY.SEAS_HASDATAAVAILABILITY ), availability.serialize(model) )
+			entity.addProperty( model.createProperty( PROPERTY.HASDATAAVAILABILITY ), availability.serialize(model) )
 
 		# capacities
 		for cap in self.capacities:
-			entity.addProperty(model.createProperty( PROPERTY.SEAS_CAPACITY ), cap.serialize(model))
+			entity.addProperty(model.createProperty( PROPERTY.CAPACITY ), cap.serialize(model))
 		
 		# set interfaces
 		for iAddrs in self.interfaces:
-			entity.addProperty(model.createProperty( PROPERTY.SEAS_INTERFACE ), iAddrs.serialize(model))
+			entity.addProperty(model.createProperty( PROPERTY.INTERFACE ), iAddrs.serialize(model))
 		
 		# set owners
 		for owner in self.owners:
-			entity.addProperty(model.createProperty( PROPERTY.SEAS_OWNER ), owner.serialize(model))
+			entity.addProperty(model.createProperty( PROPERTY.OWNER ), owner.serialize(model))
 			
 		# set creators
 		for creator in self.creators:
-			entity.addProperty(model.createProperty( PROPERTY.DC_CREATOR ), creator.serialize(model))
+			entity.addProperty(model.createProperty( PROPERTY.CREATOR ), creator.serialize(model))
 			
 		# capabilites
-		hasCapabilityProp = model.createProperty( PROPERTY.SEAS_HASCAPABILITY )
+		hasCapabilityProp = model.createProperty( PROPERTY.HASCAPABILITY )
 		if self.hasCapability():
 			for activity in self.capabilities:
 				activityRes = activity.serialize(model)
@@ -77,25 +77,25 @@ class Entity(Obj):
 		
 		# websites
 		if self.hasWebsite():
-			websiteProp = model.createProperty( PROPERTY.VCARD_HASURL )
+			websiteProp = model.createProperty( PROPERTY.HASURL )
 			for website in self.relatedUrls["siteurls"]:
 				entity.addProperty( websiteProp, website );
 			
 		# logos
 		if self.hasLogo():
-			logoProp = model.createProperty( PROPERTY.VCARD_HASLOGO )
+			logoProp = model.createProperty( PROPERTY.HASLOGO )
 			for logo in self.relatedUrls["logos"]:
 				entity.addProperty( logoProp, logo );
 			
 		# photos
 		if self.hasPhoto():
-			photoProp = model.createProperty( PROPERTY.VCARD_HASPHOTO )
+			photoProp = model.createProperty( PROPERTY.HASPHOTO )
 			for photo in self.relatedUrls["photos"]:
 				entity.addProperty( photoProp, photo );
 			
 		# sounds
 		if self.hasSound():
-			soundProp = model.createProperty( PROPERTY.VCARD_HASSOUND )
+			soundProp = model.createProperty( PROPERTY.HASSOUND )
 			for sound in self.relatedUrls["sounds"]:
 				entity.addProperty( soundProp, sound )
 		
@@ -130,7 +130,7 @@ class Entity(Obj):
 			predicate = str(statement.getPredicate())
 	
 			# zone
-			if predicate == PROPERTY.SEAS_ZONE:
+			if predicate == PROPERTY.ZONE:
 				try:
 					self.setZone(Zone().parse(statement.getResource()))
 				except:
@@ -140,19 +140,19 @@ class Entity(Obj):
 				return
 	
 			# coordinates
-			if predicate == PROPERTY.SEAS_LOCATION:
+			if predicate == PROPERTY.LOCATION:
 				try:
 					self.setCoordinates(Coordinates().parse(statement.getResource()))
 				except:
-					print "Unable to interpret seas:location value as resource."
+					print "Unable to interpret geo:location value as resource."
 					print sys.exc_info()[1]
 					traceback.print_exc()
 				return
 	
 				# coordinates
-			if predicate == PROPERTY.VCARD_HASADDRESS:
+			if predicate == PROPERTY.HASADDRESS:
 				try:
-					self.setLocation(Address().parse(statement.getResource()))
+					self.setAddress(Address().parse(statement.getResource()))
 				except:
 					print "Unable to interpret vcard:hasAddress value as resource."
 					print sys.exc_info()[1]
@@ -160,7 +160,7 @@ class Entity(Obj):
 				return
 			
 			# controllability
-			if predicate == PROPERTY.SEAS_HASEVALUATION:
+			if predicate == PROPERTY.HASEVALUATION:
 				try:
 					self.addControllability(Controllability().parse(statement.getResource()))
 				except:
@@ -169,7 +169,7 @@ class Entity(Obj):
 				return
 	
 			# availability
-			if predicate == PROPERTY.SEAS_HASAVAILABILITY:
+			if predicate == PROPERTY.HASAVAILABILITY:
 				try:
 					self.addAvailability(Availability().parse(statement.getResource()))
 				except:
@@ -178,7 +178,7 @@ class Entity(Obj):
 				return
 	
 			# data availability
-			if predicate == PROPERTY.SEAS_HASDATAAVAILABILITY:
+			if predicate == PROPERTY.HASDATAAVAILABILITY:
 				try:
 					self.addDataAvailability(Availability().parse(statement.getResource()))
 				except:
@@ -187,7 +187,7 @@ class Entity(Obj):
 				return
 	
 			# hascapability
-			if predicate == PROPERTY.SEAS_HASCAPABILITY:
+			if predicate == PROPERTY.HASCAPABILITY:
 				try:
 					self.addCapability(Activity().parse(statement.getResource()))
 				except:
@@ -196,7 +196,7 @@ class Entity(Obj):
 				return
 			
 			# capacity
-			if predicate == PROPERTY.SEAS_CAPACITY:
+			if predicate == PROPERTY.CAPACITY:
 				try:
 					self.addCapacity(Evaluation().parse(statement.getResource()))
 				except:
@@ -205,62 +205,69 @@ class Entity(Obj):
 				return
 	
 			# interfaceaddress
-			if predicate == PROPERTY.SEAS_INTERFACE:
+			if predicate == PROPERTY.INTERFACE:
 				try:
 					self.addInterface(InterfaceAddress().parse(statement.getResource()))
 				except:
 					print "Unable to interpret seas:interface value as resource."
 					traceback.print_exc() 
-
+				return
+			
 			# creators
-			if predicate == PROPERTY.DC_CREATOR:
+			if predicate == PROPERTY.CREATOR:
 				try:
 					self.addCreator(Entity().parse(statement.getResource()))
 				except:
 					print "Unable to interpret dc:creator value as resource."
 					traceback.print_exc()
+				return 
 			
 			# owner
-			if predicate == PROPERTY.SEAS_OWNER:
+			if predicate == PROPERTY.OWNER:
 				try:
 					self.addOwner(Entity().parse(statement.getResource()))
 				except:
 					print "Unable to interpret seas:owner value as resource."
 					traceback.print_exc() 
-
+				return
+			
  			# website
-		 	if predicate == PROPERTY.VCARD_HASURL:
+		 	if predicate == PROPERTY.HASURL:
 				try:
 					self.addWebsite(statement.getString());
 				except:
 					print "Unable to interpret vcard:hasURL value as string literal."
 					traceback.print_exc() 
-
+				return
+			
 			# logo
-			if predicate == PROPERTY.VCARD_HASLOGO:
+			if predicate == PROPERTY.HASLOGO:
 				try:
 					self.addLogo(statement.getString());
 				except:
 					print "Unable to interpret vcard:hasLogo value as string literal."
 					traceback.print_exc()
-
+				return
+			
 			# photo
-			if predicate == PROPERTY.VCARD_HASPHOTO:
+			if predicate == PROPERTY.HASPHOTO:
 				try:
 					self.addPhoto(statement.getString());
 				except:
 					print "Unable to interpret vcard:hasPhoto value as string literal."
 					traceback.print_exc()
-
+				return
+			
 			# sound
-			if predicate == PROPERTY.VCARD_HASSOUND:
+			if predicate == PROPERTY.HASSOUND:
 				try:
 					self.addSound(statement.getString());
 				except:
 					print "Unable to interpret vcard:hasSound value as string literal."
 					traceback.print_exc()
-		
-		# pass on to Object
+				return
+			
+			# pass on to Object
 			super(Entity, self).parse(statement)
 
 	
@@ -292,7 +299,7 @@ class Entity(Obj):
 		self.address = a
 
 	def hasControllability(self):
-		return len(controllabilities) > 0
+		return len(self.controllabilities) > 0
 	
 	def getControllabilities(self):
 		return self.controllabilities
@@ -310,7 +317,7 @@ class Entity(Obj):
 		self.availabilities.append(availability)
 
 	def hasDataAvailability(self):
-		return len(dataAvailabilities) > 0
+		return len(self.dataAvailabilities) > 0
 	
 	def getDataAvailabilities(self):
 		return self.dataAvailabilities
@@ -427,4 +434,4 @@ class Entity(Obj):
 		if self.hasSound(): 	list = self.getSounds()
 		list.append(url)
 		self.relatedUrls["sounds"] = list
-	
\ No newline at end of file
+	
