@@ -6,10 +6,11 @@ from SeasObjects.model.Map import Map
 from SeasObjects.model.Service import Service
 
 from SeasObjects.rdf.Resource import Resource
+from SeasObjects.rdf.Property import Property
 from SeasObjects.rdf.Statement import Statement
-from SeasObjects.rdf.RdfList import RdfList
 from SeasObjects.rdf.types import *
 from rdflib import URIRef
+from rdflib.namespace import RDF
 
 from SeasObjects.seasexceptions.NonePointerException import NonePointerException
 
@@ -20,7 +21,7 @@ class Evaluation(Obj):
 
 	def __init__(self, uri = None):
 		Obj.__init__(self, uri)
-		self.setType(RESOURCE.SEAS_EVALUATION)
+		self.setType(RESOURCE.EVALUATION)
 		self.categories = []
 		self.entities = []
 		self.timeSeries = []
@@ -50,109 +51,113 @@ class Evaluation(Obj):
 
 		# categoriess
 		for category in self.categories:
-			resource.addProperty( model.createProperty( PROPERTY.SEAS_CATEGORY ), model.createResource( category ) )
+			resource.addProperty( model.createProperty( PROPERTY.CATEGORY ), model.createResource( category ) )
 
 		# entities
 		for entity in self.entities:
-			resource.addProperty( model.createProperty( PROPERTY.SEAS_ENTITY ), entity.serialize(model) )
+			resource.addProperty( model.createProperty( PROPERTY.ENTITY ), entity.serialize(model) )
 
 		# timeseries
 		for timeSerie in self.timeSeries:
-			resource.addProperty( model.createProperty( PROPERTY.SEAS_TIMESERIES ), timeSerie.serialize(model) )
+			resource.addProperty( model.createProperty( PROPERTY.TIMESERIES ), timeSerie.serialize(model) )
 
 		# generatedby
 		if self.hasGeneratedBy():
-			resource.addProperty( model.createProperty( PROPERTY.SEAS_GENERATEDBY ), self.generatedBy.serialize(model) )
+			resource.addProperty( model.createProperty( PROPERTY.GENERATEDBY ), self.generatedBy.serialize(model) )
 		
 		# generatedat
 		if self.hasGeneratedAt():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_GENERATEDAT ), model.createLiteral(self.getGeneratedAt()))
+			resource.addProperty(model.createProperty( PROPERTY.GENERATEDAT ), model.createLiteral(self.getGeneratedAt()))
 
 		# systemOfInterest
 		if self.hasSystemOfInterest():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_SYSTEMOFINTEREST ), self.systemOfInterest.serialize(model))
+			resource.addProperty(model.createProperty( PROPERTY.SYSTEMOFINTEREST ), self.systemOfInterest.serialize(model))
 
 		# temporalcontext
 		if self.hasTemporalContext():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_TEMPORALCONTEXT ), self.temporalContext.serialize(model))
+			resource.addProperty(model.createProperty( PROPERTY.TEMPORALCONTEXT ), self.temporalContext.serialize(model))
 
 		# set interfaces
 		for iAddrs in self.interfaces:
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_INTERFACE ), iAddrs.serialize(model))
+			resource.addProperty(model.createProperty( PROPERTY.INTERFACE ), iAddrs.serialize(model))
 
 		# quantity
 		if self.hasQuantity():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_QUANTITY ), model.createResource(self.quantity))
+			resource.addProperty(model.createProperty( PROPERTY.QUANTITYKIND ), model.createResource(self.quantity))
 
 		# instant
 		if self.hasInstant():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_INSTANT ), model.createLiteral(self.instant))
+			resource.addProperty(model.createProperty( PROPERTY.INSTANT ), model.createLiteral(self.instant))
 
 		# unit
 		if self.hasUnit():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_UNIT ), model.createResource(self.unit))
+			resource.addProperty(model.createProperty( PROPERTY.UNIT ), model.createResource(self.unit))
 		
 		# value
 		if self.hasValue():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_VALUE ), self.value.serialize(model))
+			resource.addProperty(model.createProperty( PROPERTY.RDF_VALUE ), self.value.serialize(model))
 
 		# minimum
 		if self.hasMinimum():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_MINIMUM ), self.minimum.serialize(model))
+			resource.addProperty(model.createProperty( PROPERTY.MINIMUM ), self.minimum.serialize(model))
 
 		# maximum
 		if self.hasMaximum():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_MAXIMUM ), self.maximum.serialize(model))
+			resource.addProperty(model.createProperty( PROPERTY.MAXIMUM ), self.maximum.serialize(model))
 
 		# valueobjects
-		valueobjProp = model.createProperty( PROPERTY.SEAS_VALUEOBJECT )
+		valueobjProp = model.createProperty( PROPERTY.VALUEOBJECT )
 		for valueObject in self.valueObjects:
 			resource.addProperty( valueobjProp, valueObject.serialize(model) )
 
 		# inputs
 		for input in self.inputs:
 			if input.getInputType() == Input.TYPE_DATA:
-				resource.addProperty(model.createProperty( PROPERTY.SEAS_HASINPUT ), input.serialize(model))
+				resource.addProperty(model.createProperty( PROPERTY.HASINPUT ), input.serialize(model))
 			if input.getInputType() == Input.TYPE_REFERENCE:
-				resource.addProperty(model.createProperty( PROPERTY.SEAS_HASREFINPUT ), input.serialize(model))	
+				resource.addProperty(model.createProperty( PROPERTY.HASREFINPUT ), input.serialize(model))	
 
 		# outputs
 		for output in self.outputs:
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_HASOUTPUT ), output.serialize(model))
+			resource.addProperty(model.createProperty( PROPERTY.HASOUTPUT ), output.serialize(model))
 
 		# set activities
 		for activity in self.activities:
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_ACTIVITY ), activity.serialize(model))
+			resource.addProperty(model.createProperty( PROPERTY.ACTIVITY ), activity.serialize(model))
 
 		"""
 		for parameter in self.parameters:
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_PARAMETER ), parameter.serialize(model))
+			resource.addProperty(model.createProperty( PROPERTY.PARAMETER ), parameter.serialize(model))
 		"""
 		
 		# list
 		if self.hasList():
-			rdfList = model.createList()
+			rdfList = model.createOrderedList()
 			for i in range(len(self.list)):
 				rdfList.add_items(self.list[i].serialize(model))
-			resource.addProperty(model.createProperty(PROPERTY.SEAS_LIST), rdfList)
+			
+			listContainer = model.createResource()
+			listContainer.addProperty(Property(RDF.first), rdfList)
+			resource.addProperty(model.createProperty(PROPERTY.RDF_VALUE), listContainer)
+			resource.addProperty(model.createProperty(PROPERTY.LIST), listContainer)
 
 		# map
 		if self.hasMap():
-			resource.addProperty(model.createProperty(PROPERTY.SEAS_MAP), self.map.serialize(model))
+			resource.addProperty(model.createProperty(PROPERTY.MAP), self.map.serialize(model))
 	
 		return resource
 
 
 	def fromString(self, data, serialization):
 		try :
-			return Evaluation.parse(Tools().getResourceByType(RESOURCE.SEAS_EVALUATION, Tools().fromString(data, serialization)));
+			return Evaluation.parse(Tools().getResourceByType(RESOURCE.EVALUATION, Tools().fromString(data, serialization)));
 		except:
 			print "Unable to parse Evaluation from the given string."
 			traceback.print_exc()
 			return None
 	
 	def parse(self, element):
-		from SeasObjects.model.Variant import Variant
+		from SeasObjects.rdf.Variant import Variant
 		from SeasObjects.model.Activity import Activity
 		from SeasObjects.model.Device import Device
 		from SeasObjects.model.Entity import Entity
@@ -187,7 +192,7 @@ class Evaluation(Obj):
 			predicate = str(statement.getPredicate())
 			
 			# category
-			if predicate == PROPERTY.SEAS_CATEGORY:
+			if predicate == PROPERTY.CATEGORY:
 				try:
 					self.addCategory(str(statement.getResource().toString()))
 				except:
@@ -196,7 +201,7 @@ class Evaluation(Obj):
 				return
 	
 			# systemofinterest
-			if predicate == PROPERTY.SEAS_SYSTEMOFINTEREST:
+			if predicate == PROPERTY.SYSTEMOFINTEREST:
 				try:
 					self.setSystemOfInterest(SystemOfInterest().parse(statement.getResource()))
 				except:
@@ -205,7 +210,7 @@ class Evaluation(Obj):
 				return
 	
 			# temporalcontext
-			if predicate == PROPERTY.SEAS_TEMPORALCONTEXT:
+			if predicate == PROPERTY.TEMPORALCONTEXT:
 				try:
 					self.setTemporalContext(TemporalContext().parse(statement.getResource()))
 				except:
@@ -214,7 +219,7 @@ class Evaluation(Obj):
 				return
 	
 			# interfaceaddress
-			if predicate == PROPERTY.SEAS_INTERFACE:
+			if predicate == PROPERTY.INTERFACE:
 				try:
 					self.addInterface(InterfaceAddress().parse(statement.getResource()))
 				except:
@@ -223,7 +228,7 @@ class Evaluation(Obj):
 				return
 	
 			# timeserie
-			if predicate == PROPERTY.SEAS_TIMESERIES:
+			if predicate == PROPERTY.TIMESERIES:
 				try:
 					self.addTimeSerie(TimeSeries().parse(statement.getResource()))
 				except:
@@ -232,7 +237,7 @@ class Evaluation(Obj):
 				return
 	
 			# quantity
-			if predicate == PROPERTY.SEAS_QUANTITY:
+			if predicate == PROPERTY.QUANTITYKIND:
 				try:
 					self.setQuantity(statement.getResource().toString())
 				except:
@@ -241,7 +246,7 @@ class Evaluation(Obj):
 				return;
 	
 			# unit
-			if predicate == PROPERTY.SEAS_UNIT:
+			if predicate == PROPERTY.UNIT:
 				try:
 					self.setUnit(statement.getResource().toString())
 				except:
@@ -250,7 +255,7 @@ class Evaluation(Obj):
 				return
 	
 			# instant
-			if predicate == PROPERTY.SEAS_INSTANT:
+			if predicate == PROPERTY.INSTANT:
 				try:
 					self.setInstant(statement.getObject().toPython())
 				except:
@@ -259,22 +264,22 @@ class Evaluation(Obj):
 				return
 	
 			# value
-			if predicate == PROPERTY.SEAS_VALUE:
+			if predicate == PROPERTY.RDF_VALUE:
 				self.setValue(Variant().parse(statement))
 				return
 	
 			# minimum
-			if predicate == PROPERTY.SEAS_MINIMUM:
+			if predicate == PROPERTY.MINIMUM:
 				self.setMinimum(Variant().parse(statement))
 				return
 	
 			# maximum
-			if predicate == PROPERTY.SEAS_MAXIMUM:
+			if predicate == PROPERTY.MAXIMUM:
 				self.setMaximum(Variant().parse(statement))
 				return
 	
 			# valueobject
-			if predicate == PROPERTY.SEAS_VALUEOBJECT:
+			if predicate == PROPERTY.VALUEOBJECT:
 				try:
 					self.addValueObject(ValueObject().parse(statement.getResource()))
 				except:
@@ -283,7 +288,7 @@ class Evaluation(Obj):
 				return
 	
 			# input data
-			if predicate == PROPERTY.SEAS_HASINPUT:
+			if predicate == PROPERTY.HASINPUT:
 				try:
 					self.addInput(Input().parse(statement.getResource()))
 				except:
@@ -292,7 +297,7 @@ class Evaluation(Obj):
 				return
 	
 			# input reference
-			if predicate == PROPERTY.SEAS_HASREFINPUT:
+			if predicate == PROPERTY.HASREFINPUT:
 				try:
 					input = Input().parse(statement.getResource())
 					input.setInputType(Input.TYPE_REFERENCE)
@@ -303,7 +308,7 @@ class Evaluation(Obj):
 				return
 	
 			# output
-			if predicate == PROPERTY.SEAS_HASOUTPUT:
+			if predicate == PROPERTY.HASOUTPUT:
 				try:
 					self.addOutput(Output().parse(statement.getResource()));
 				except:
@@ -312,7 +317,7 @@ class Evaluation(Obj):
 				return
 			
 			# activities
-			if predicate == PROPERTY.SEAS_ACTIVITY:
+			if predicate == PROPERTY.ACTIVITY:
 				try:
 					self.addActivity(Activity().parse(statement.getResource()))
 				except:
@@ -321,7 +326,7 @@ class Evaluation(Obj):
 				return
 			
 			""""
-			if predicate == PROPERTY.SEAS_PARAMETER:
+			if predicate == PROPERTY.PARAMETER:
 				try:
 					self.addParameter(Parameter().parse(statement.getResource()))
 				except:
@@ -331,7 +336,7 @@ class Evaluation(Obj):
 			"""
 			
 			# entity
-			if predicate == PROPERTY.SEAS_ENTITY:
+			if predicate == PROPERTY.ENTITY:
 				types = None
 				try:
 					types = Tools().getResourceTypes(statement.getResource())
@@ -340,7 +345,7 @@ class Evaluation(Obj):
 					traceback.print_exc()
 	
 				# service
-				if types is not None and RESOURCE.SEAS_SERVICE in types:
+				if types is not None and RESOURCE.SERVICE in types:
 					try:
 						self.addEntity(Service().parse(statement.getResource()))
 					except:
@@ -349,7 +354,7 @@ class Evaluation(Obj):
 					return
 	
 				# device
-				if types is not None and RESOURCE.SEAS_DEVICE in types:
+				if types is not None and RESOURCE.DEVICE in types:
 					try:
 						self.addEntity(Device().parse(statement.getResource()))
 					except:
@@ -371,7 +376,7 @@ class Evaluation(Obj):
 				return
 	
 			# generatedby
-			if predicate == PROPERTY.SEAS_GENERATEDBY:
+			if predicate == PROPERTY.GENERATEDBY:
 				try:
 					self.setGeneratedBy(Activity().parse(statement.getResource()))
 				except:
@@ -380,7 +385,7 @@ class Evaluation(Obj):
 				return
 			
 			# generatedat
-			if predicate == PROPERTY.SEAS_GENERATEDAT:
+			if predicate == PROPERTY.GENERATEDAT:
 				try:
 					self.setGeneratedAt(statement.getObject().toPython())
 				except:
@@ -389,7 +394,7 @@ class Evaluation(Obj):
 				return
 	
 			# generatedat
-			if predicate == PROPERTY.SEAS_LIST:
+			if predicate == PROPERTY.LIST:
 				try:
 					self.setList(statement.getResource().toList(Evaluation))
 				except:
@@ -398,7 +403,7 @@ class Evaluation(Obj):
 				return
 	
 			# generatedat
-			if predicate == PROPERTY.SEAS_MAP:
+			if predicate == PROPERTY.MAP:
 				try:
 					self.setMap(Map().parse(statement.getResource()))
 				except:
@@ -602,7 +607,7 @@ class Evaluation(Obj):
 	"""
 	
 	def addParameter(self, p):
-		self.add(RESOURCE.SEAS_PARAMETER, p)
+		self.add(RESOURCE.PARAMETER, p)
 
 	def hasList(self):
 		return len(self.list) > 0
@@ -624,4 +629,22 @@ class Evaluation(Obj):
 	
 	def setMap(self, _map):
 		self.map = _map
-	
\ No newline at end of file
+	
+	def firstActivity(self):
+		try:
+			return self.activities[0]
+		except:
+			return None
+    
+	def firstInput(self):
+		try:
+			return self.inputs[0]
+		except:
+			return None
+    
+	def firstOutput(self):
+		try:
+			return self.outputs[0]
+		except:
+			return None
+    
