@@ -15,7 +15,7 @@ class Orientation(Obj):
 		self.yaw = None
 		self.pitch = None
 		self.roll = None
-		self.setType(RESOURCE.SEAS_ORIENTATION);
+		self.setType(RESOURCE.ORIENTATION);
 	
 	def hasYaw(self):
 		return self.yaw is not None
@@ -48,13 +48,13 @@ class Orientation(Obj):
 		orientation = super(Orientation, self).serialize(model)
 		
 		if self.hasPitch():
-			orientation.addProperty(model.createProperty( PROPERTY.SEAS_PITCH ), self.getPitch().serialize(model))
+			orientation.addProperty(model.createProperty( PROPERTY.PITCH ), self.getPitch().serialize(model))
 
 		if self.hasYaw():
-			orientation.addProperty(model.createProperty( PROPERTY.SEAS_YAW ), self.getYaw().serialize(model))
+			orientation.addProperty(model.createProperty( PROPERTY.YAW ), self.getYaw().serialize(model))
 
 		if self.hasRoll():
-			orientation.addProperty(model.createProperty( PROPERTY.SEAS_ROLL ), self.getRoll().serialize(model))
+			orientation.addProperty(model.createProperty( PROPERTY.ROLL ), self.getRoll().serialize(model))
 
 		return orientation
 	
@@ -77,7 +77,7 @@ class Orientation(Obj):
 			predicate = str(statement.getPredicate())
 	
 			# pitch
-			if predicate == PROPERTY.SEAS_PITCH:
+			if predicate == PROPERTY.PITCH:
 				try:
 					self.setPitch(ValueObject().parse(statement.getResource()))
 				except:
@@ -86,7 +86,7 @@ class Orientation(Obj):
 				return
 	
 			# yaw
-			if predicate == PROPERTY.SEAS_YAW:
+			if predicate == PROPERTY.YAW:
 				try:
 					self.setYaw(ValueObject().parse(statement.getResource()))
 				except:
@@ -95,7 +95,7 @@ class Orientation(Obj):
 				return
 			
 			# roll
-			if predicate == PROPERTY.SEAS_ROLL:
+			if predicate == PROPERTY.ROLL:
 				try:
 					self.setRoll(ValueObject().parse(statement.getResource()))
 				except:
