@@ -2,24 +2,26 @@ from SeasObjects.common.PROPERTY import PROPERTY
 from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.model.Evaluation import Evaluation
 
+import traceback
+
 class Output(Evaluation):
 
 	def __init__(self, uri = None):
 		Evaluation.__init__(self, uri)
 		self.availabilities = []
 		self.dataAvailabilities = []
-		self.setType(RESOURCE.SEAS_OUTPUT)
+		self.setType(RESOURCE.OUTPUT)
 	
 	def serialize(self, model):
 		output = super(Output, self).serialize(model)
 		
 		# availability
-		availabilityProp = model.createProperty( PROPERTY.SEAS_HASAVAILABILITY )
+		availabilityProp = model.createProperty( PROPERTY.HASAVAILABILITY )
 		for availability in self.availabilities:
 			output.addProperty( availabilityProp, availability.serialize(model) )
 
 		# data availability
-		dataAvailabilityProp = model.createProperty( PROPERTY.SEAS_HASDATAAVAILABILITY )
+		dataAvailabilityProp = model.createProperty( PROPERTY.HASDATAAVAILABILITY )
 		for availability in self.dataAvailabilities:
 			output.addProperty( dataAvailabilityProp, availability.serialize(model) )
 
@@ -40,7 +42,7 @@ class Output(Evaluation):
 			predicate = str(statement.getPredicate())
 
 			# availability
-			if predicate == PROPERTY.SEAS_HASAVAILABILITY:
+			if predicate == PROPERTY.HASAVAILABILITY:
 				try:
 					output.addAvailability(Availability().parse(statement.getResource()))
 				except:
@@ -49,7 +51,7 @@ class Output(Evaluation):
 				continue
 
 			# data availability
-			if predicate == PROPERTY.SEAS_HASDATAAVAILABILITY:
+			if predicate == PROPERTY.HASDATAAVAILABILITY:
 				try:
 					output.addDataAvailability(Availability().parse(statement.getResource()))
 				except:
