@@ -10,7 +10,7 @@ class Person(PhysicalEntity):
 
 	def __init__(self, uri = None):
 		PhysicalEntity.__init__(self, uri)
-		self.setType(RESOURCE.SEAS_PERSON)
+		self.setType(RESOURCE.PERSON)
 
 	def serialize(self, model):
 		p = super(Person, self).serialize(model)
@@ -28,7 +28,7 @@ class Person(PhysicalEntity):
 				# parse statement
 				p.parse(statement);
 	
-			return activity
+			return p
 		
 		else:
 			statement = resource
