@@ -4,6 +4,7 @@ from SeasObjects.common.Tools import Tools
 
 from SeasObjects.model.Message import Message
 from SeasObjects.rdf.Resource import Resource
+from SeasObjects.seasexceptions.NonePointerException import NonePointerException
 
 import traceback
 import sys
@@ -13,7 +14,7 @@ class Request(Message):
 
 	def __init__(self, uri = None):
 		Message.__init__(self, uri)
-		self.setType(RESOURCE.SEAS_REQUEST)
+		self.setType(RESOURCE.REQUEST)
 		
 	def serialize(self, model):
 		r = super(Request, self).serialize(model)
@@ -21,7 +22,7 @@ class Request(Message):
 	
 	def fromString(self, data, serialization):
 		try:
-			return Request.parse(Tools().getResourceByType(RESOURCE.SEAS_REQUEST, Tools().fromString(data, serialization)));
+			return Request.parse(Tools().getResourceByType(RESOURCE.REQUEST, Tools().fromString(data, serialization)));
 		except:
 			print "Unable to parse Request from the given string."
 			traceback.print_exc() 
@@ -30,7 +31,7 @@ class Request(Message):
 	def parse(self, resource):
 		if isinstance(resource, Resource):
 			if resource is None:
-				raise NullPointerException("Unable to parse null to Request.")
+				raise NonePointerException("Unable to parse null to Request.")
 			
 			if not resource.isAnon():
 				request = Request(resource.toString())
