@@ -4,12 +4,15 @@ from SeasObjects.common.Tools import Tools
 
 from SeasObjects.rdf.Resource import Resource
 from SeasObjects.model.Message import Message
+from SeasObjects.seasexceptions.NonePointerException import NonePointerException
+
+import traceback
 
 class Response(Message):
 	
 	def __init__(self, uri = None):
 		Message.__init__(self, uri)
-		self.setType(RESOURCE.SEAS_RESPONSE)
+		self.setType(RESOURCE.RESPONSE)
 
 	def serialize(self, model):
 		resource = super(Response, self).serialize(model)
@@ -18,7 +21,7 @@ class Response(Message):
 
 	def fromString(self, data, serialization):
 		try:
-			return self.parse(Tools().getResourceByType(RESOURCE.SEAS_RESPONSE, Tools().fromString(data, serialization)))
+			return self.parse(Tools().getResourceByType(RESOURCE.RESPONSE, Tools().fromString(data, serialization)))
 		except:
 			print "Unable to parse Response from the given string."
 			traceback.print_exc() 
@@ -27,7 +30,7 @@ class Response(Message):
 	def parse(self, resource):
 		if isinstance(resource, Resource):
 			if resource == None:
-				raise NullPointerException("Unable to parse null to Response.")
+				raise NonePointerException("Unable to parse null to Response.")
 	
 			if not resource.isAnon():
 				response = Response(resource.toString())
