@@ -17,7 +17,7 @@ class Ring(Obj):
 		self.minRadius = None
 		self.maxRadius = None
 		self.coordinates = None
-		self.setType(RESOURCE.SEAS_RING)
+		self.setType(RESOURCE.RING)
 
 	def hasCoordinates(self):
 		return self.coordinates is not None
@@ -51,15 +51,15 @@ class Ring(Obj):
 	
 		# coordinates
 		if self.hasCoordinates():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_COORDINATES ), self.coordinates.serialize(model))
+			resource.addProperty(model.createProperty( PROPERTY.LOCATION ), self.coordinates.serialize(model))
 				
 		# min radius
 		if self.hasMinRadius():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_MINRADIUS ), self.minRadius.serialize(model))
+			resource.addProperty(model.createProperty( PROPERTY.MINRADIUS ), self.minRadius.serialize(model))
 		
 		# max radius
 		if self.hasMaxRadius():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_MAXRADIUS ), self.maxRadius.serialize(model))
+			resource.addProperty(model.createProperty( PROPERTY.MAXRADIUS ), self.maxRadius.serialize(model))
 		
 		return resource
 
@@ -83,7 +83,7 @@ class Ring(Obj):
 			predicate = str(statement.getPredicate())
 	
 			# latitude
-			if predicate == PROPERTY.SEAS_COORDINATES:
+			if predicate == PROPERTY.LOCATION:
 				try:
 					self.setCoordinates(Coordinates().parse(statement.getResource()))
 				except:
@@ -91,7 +91,7 @@ class Ring(Obj):
 					traceback.print_exc()
 				return
 		
-			if predicate == PROPERTY.SEAS_MINRADIUS:
+			if predicate == PROPERTY.MINRADIUS:
 				try:
 					self.setMinRadius(ValueObject().parse(statement.getResource()))
 				except:
@@ -99,7 +99,7 @@ class Ring(Obj):
 					traceback.print_exc()
 				return
 	
-			if predicate == PROPERTY.SEAS_MAXRADIUS:
+			if predicate == PROPERTY.MAXRADIUS:
 				try:
 					self.setMaxRadius(ValueObject().parse(statement.getResource()))
 				except:
