@@ -1,15 +1,19 @@
 from SeasObjects.common.PROPERTY import PROPERTY
 from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.rdf.Resource import Resource
+from SeasObjects.rdf.Property import Property
 from SeasObjects.model.Obj import Obj
 from SeasObjects.model.Coordinates import Coordinates
+from rdflib.namespace import RDF
+
+import traceback
 
 
 class Route(Obj):
 	
 	def __init__(self, uri = None):
 		Obj.__init__(self, uri)
-		self.setType(RESOURCE.SEAS_ROUTE)
+		self.setType(RESOURCE.ROUTE)
 		self.route_points = []
 		self.length = None
 		self.energyConsumption = None
@@ -32,22 +36,25 @@ class Route(Obj):
 		route = super(Route, self).serialize(model)
 		
 		if self.hasRoutePoints():
-			rdfList = model.createList()
+			rdfList = model.createNudeList()
 			rdfList.add_items(self.route_points)
 			
-			route.addProperty(model.createProperty( PROPERTY.SEAS_LIST ), rdfList)
+			listContainer = model.createResource()
+			listContainer.addProperty(Property(RDF.first), rdfList)
+			
+			route.addProperty(model.createProperty( PROPERTY.LIST ), listContainer)
 
 		if self.hasLength():
-			route.addProperty(model.createProperty( PROPERTY.SEAS_LENGTH ), self.length.serialize(model));
+			route.addProperty(model.createProperty( PROPERTY.LENGTH ), self.length.serialize(model));
 		
 		if self.hasEnergyConsumption():
-			route.addProperty(model.createProperty( PROPERTY.SEAS_ENERGYCONSUMPTION ), self.energyConsumption.serialize(model));
+			route.addProperty(model.createProperty( PROPERTY.ENERGYCONSUMPTION ), self.energyConsumption.serialize(model));
 		
 		if self.hasAverageVelocity():
-			route.addProperty(model.createProperty( PROPERTY.SEAS_AVERAGESPEED ), self.averageVelocity.serialize(model));
+			route.addProperty(model.createProperty( PROPERTY.AVERAGEVELOCITY ), self.averageVelocity.serialize(model));
 		
 		if self.hasDuration():
-			route.addProperty(model.createProperty( PROPERTY.SEAS_DURATION ), self.duration.serialize(model));
+			route.addProperty(model.createProperty( PROPERTY.DURATION ), self.duration.serialize(model));
 		
 		return route
 	
@@ -75,7 +82,7 @@ class Route(Obj):
 			predicate = str(statement.getPredicate())
 
 			# route points
-			if predicate == PROPERTY.SEAS_LIST:
+			if predicate == PROPERTY.LIST:
 				try:
 					self.setRoutePoints(statement.getResource().toList(Coordinates))
 				except:
@@ -84,7 +91,7 @@ class Route(Obj):
 				return
 			
 			
-			if predicate == PROPERTY.SEAS_LENGTH:
+			if predicate == PROPERTY.LENGTH:
 				try:
 					self.setLength(ValueObject().parse(statement.getResource()))
 				except:
@@ -92,7 +99,7 @@ class Route(Obj):
 					traceback.print_exc() 
 				return
 			
-			if predicate == PROPERTY.SEAS_ENERGYCONSUMPTION:
+			if predicate == PROPERTY.ENERGYCONSUMPTION:
 				try:
 					self.setEnergyConsumption(ValueObject().parse(statement.getResource()))
 				except:
@@ -100,15 +107,15 @@ class Route(Obj):
 					traceback.print_exc() 
 				return
 
-			if predicate == PROPERTY.SEAS_AVERAGESPEED:
+			if predicate == PROPERTY.AVERAGEVELOCITY:
 				try:
 					self.setAverageVelocity(Velocity().parse(statement.getResource()))
 				except:
-					print "Unable to interpret seas:averagesoeed value as a resource for Route."
+					print "Unable to interpret seas:averageSpeed value as a resource for Route."
 					traceback.print_exc() 
 				return
 
-			if predicate == PROPERTY.SEAS_DURATION:
+			if predicate == PROPERTY.DURATION:
 				try:
 					self.setDuration(TemporalContext().parse(statement.getResource()))
 				except:
@@ -155,4 +162,4 @@ class Route(Obj):
 	
 	def setDuration(self, l):
 		self.duration = l
-		
\ No newline at end of file
+		
