@@ -2,6 +2,7 @@ from SeasObjects.common.PROPERTY import PROPERTY
 from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.model.AbstractEntity import AbstractEntity
 from SeasObjects.rdf.Resource import Resource
+from SeasObjects.model.Obj import Obj
 
 import traceback
 
@@ -11,17 +12,17 @@ class Service(AbstractEntity):
 	def __init__(self, uri = None):
 		AbstractEntity.__init__(self, uri)
 		self.managedBy = None
-		self.setType(RESOURCE.SEAS_SERVICE);
+		self.setType(RESOURCE.SERVICE);
 
 	def hasManagedBy(self):
 		return self.managedBy is not None
 
-	def setManagedBy(self, obj):
-		self.managedBy = obj
-
-	def setManagedBy(self, uri):
-		self.managedBy = Obj(uri)
-
+	def setManagedBy(self, o):
+		if isinstance(o, Obj):
+			self.managedBy = o
+		else:
+			self.managedBy = Obj(o)
+		
 	def getManagedBy(self):
 		return self.managedBy
 	
@@ -30,7 +31,7 @@ class Service(AbstractEntity):
 		
 		# set system uri
 		if self.hasManagedBy():
-			service.addProperty(model.createProperty( PROPERTY.SEAS_ISMANAGEDBY ), self.managedBy.serialize(model))
+			service.addProperty(model.createProperty( PROPERTY.ISMANAGEDBY ), self.managedBy.serialize(model))
 
 		return service
 	
@@ -57,7 +58,7 @@ class Service(AbstractEntity):
 			predicate = str(statement.getPredicate())
 
 			# managedby
-			if predicate == PROPERTY.SEAS_ISMANAGEDBY:
+			if predicate == PROPERTY.ISMANAGEDBY:
 				try:
 					self.managedBy = Obj().parse(statement.getResource())
 				except:
