@@ -1,13 +1,16 @@
 from SeasObjects.common.PROPERTY import PROPERTY
 from SeasObjects.model.AbstractEntity import AbstractEntity
 from SeasObjects.rdf.Resource import Resource
+from SeasObjects.common.RESOURCE import RESOURCE
+
+import traceback
 
 class ServiceProvider(AbstractEntity):
 
 	def __init__(self, uri = None):
 		AbstractEntity.__init__(self, uri)
 		self.services = []
-		self.setType(RESOURCE.SEAS_SERVICEPROVIDER)
+		self.setType(RESOURCE.SERVICEPROVIDER)
 
 	def setService(self, service):
 		self.services = [service]
@@ -22,8 +25,8 @@ class ServiceProvider(AbstractEntity):
 		entity = super(ServiceProvider, self).serialize(model);
 		
 		# set services
-		offersService = model.createProperty( PROPERTY.SEAS_OFFERSSERVICE )
-		for service in services:
+		offersService = model.createProperty( PROPERTY.OFFERSSERVICE )
+		for service in self.services:
 			entity.addProperty( offersService, service.serialize(model) )
 		
 		return entity
@@ -50,7 +53,7 @@ class ServiceProvider(AbstractEntity):
 			predicate = str(statement.getPredicate())
 	
 			# offersservice
-			if predicate == PROPERTY.SEAS_OFFERSSERVICE:
+			if predicate == PROPERTY.OFFERSSERVICE:
 				try:
 					self.addService(Service().parse(statement.getResource()))
 				except:
