@@ -14,7 +14,7 @@ class Size(Obj):
 		self.height = None
 		self.width = None
 		self.depth = None
-		self.setType(RESOURCE.SEAS_SIZE);
+		self.setType(RESOURCE.SIZE);
 	
 	def hasHeight(self):
 		return self.height is not None
@@ -47,13 +47,13 @@ class Size(Obj):
 		size = super(Size, self).serialize(model)
 		
 		if self.hasWidth():
-			size.addProperty(model.createProperty( PROPERTY.SEAS_WIDTH ), self.getWidth().serialize(model))
+			size.addProperty(model.createProperty( PROPERTY.WIDTH ), self.getWidth().serialize(model))
 
 		if self.hasHeight():
-			size.addProperty(model.createProperty( PROPERTY.SEAS_HEIGHT ), self.getHeight().serialize(model))
+			size.addProperty(model.createProperty( PROPERTY.HEIGHT ), self.getHeight().serialize(model))
 
 		if self.hasDepth():
-			size.addProperty(model.createProperty( PROPERTY.SEAS_DEPTH ), self.getDepth().serialize(model))
+			size.addProperty(model.createProperty( PROPERTY.DEPTH ), self.getDepth().serialize(model))
 
 		return size
 	
@@ -76,7 +76,7 @@ class Size(Obj):
 			predicate = str(statement.getPredicate())
 	
 			# width
-			if predicate == PROPERTY.SEAS_WIDTH:
+			if predicate == PROPERTY.WIDTH:
 				try:
 					self.setWidth(ValueObject().parse(statement.getResource()))
 				except:
@@ -85,7 +85,7 @@ class Size(Obj):
 				return
 	
 			# height
-			if predicate == PROPERTY.SEAS_HEIGHT:
+			if predicate == PROPERTY.HEIGHT:
 				try:
 					self.setHeight(ValueObject().parse(statement.getResource()))
 				except:
@@ -94,7 +94,7 @@ class Size(Obj):
 				return
 			
 			# depth
-			if predicate == PROPERTY.SEAS_DEPTH:
+			if predicate == PROPERTY.DEPTH:
 				try:
 					self.setDepth(ValueObject().parse(statement.getResource()))
 				except:
