@@ -1,7 +1,7 @@
 from SeasObjects.common.PROPERTY import PROPERTY
 from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.model.Obj import Obj
-from SeasObjects.model.Variant import Variant
+from SeasObjects.rdf.Variant import Variant
 from SeasObjects.common.Tools import Tools
 
 from dateutil import parser
@@ -19,26 +19,26 @@ class TemporalContext(Obj):
 		self.end = None
 		self.duration = None
 		self.during = None
-		self.setType(RESOURCE.SEAS_TEMPORALCONTEXT)
+		self.setType(RESOURCE.TEMPORALCONTEXT)
 
 	def serialize(self, model):
 		temporalContext = super(TemporalContext, self).serialize(model);
 		
 		# start
 		if self.hasStart():
-			temporalContext.addProperty(model.createProperty( PROPERTY.SEAS_START ), model.createLiteral(self.getStart().getValue()))
+			temporalContext.addProperty(model.createProperty( PROPERTY.START ), model.createLiteral(self.getStart().getValue()))
 
 		# end
 		if self.hasEnd():
-			temporalContext.addProperty(model.createProperty( PROPERTY.SEAS_END ), model.createLiteral(self.getEnd().getValue()))
+			temporalContext.addProperty(model.createProperty( PROPERTY.END ), model.createLiteral(self.getEnd().getValue()))
 
 		# duration
 		if self.hasDuration():
-			temporalContext.addProperty(model.createProperty( PROPERTY.SEAS_DURATION ), model.createTypedLiteral(self.getDuration(), XSD.duration))
+			temporalContext.addProperty(model.createProperty( PROPERTY.DURATION ), model.createTypedLiteral(self.getDuration(), XSD.duration))
 
 		# during
 		if self.hasDuring():
-			temporalContext.addProperty(model.createProperty( PROPERTY.SEAS_DURING ), model.createResource(self.getDuring()))
+			temporalContext.addProperty(model.createProperty( PROPERTY.DURING ), model.createResource(self.getDuring()))
 
 		return temporalContext
 
@@ -55,21 +55,21 @@ class TemporalContext(Obj):
 			predicate = str(statement.getPredicate())
 
 			# start
-			if predicate == PROPERTY.SEAS_START:
+			if predicate == PROPERTY.START:
 				s = statement.getObject().toPython()
 				if not isinstance(s, datetime.datetime):
 					s = parser.parse(s)
 				temporalContext.setStart(s)
 				
 			# end
-			if predicate == PROPERTY.SEAS_END:
+			if predicate == PROPERTY.END:
 				e = statement.getObject().toPython()
 				if not isinstance(e, datetime.datetime):
 					e = parser.parse(e)
 				temporalContext.setEnd(e)
 				
 			# duration
-			if predicate == PROPERTY.SEAS_DURATION:
+			if predicate == PROPERTY.DURATION:
 				try:
 					temporalContext.setDuration(statement.getString())
 				except:
@@ -78,7 +78,7 @@ class TemporalContext(Obj):
 				continue
 
 			# during
-			if predicate == PROPERTY.SEAS_DURING:
+			if predicate == PROPERTY.DURING:
 				try:
 					temporalContext.setDuring(statement.getResource().toString())
 				except:
