@@ -2,9 +2,10 @@ from SeasObjects.common.PROPERTY import PROPERTY
 from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.rdf.Resource import Resource
 from SeasObjects.model.Obj import Obj
-from SeasObjects.model.Location import Location
+from SeasObjects.model.Coordinates import Coordinates
+from SeasObjects.model.Address import Address
 from SeasObjects.model.Route import Route
-from SeasObjects.model.Variant import Variant
+from SeasObjects.rdf.Variant import Variant
 
 import datetime
 from dateutil import parser
@@ -13,19 +14,29 @@ class Waypoint(Obj):
 	
 	def __init__(self, uri = None):
 		Obj.__init__(self, uri)
-		self.setType(RESOURCE.SEAS_WAYPOINT);
-		self.location = None
+		self.setType(RESOURCE.WAYPOINT);
+		self.coordinates = None
+		self.address = None
 		self.instant = None
 		self.route = None
 		
 	def hasLocation(self):
-		return self.location is not None
+		return self.coordinates is not None
 	
 	def getLocation(self):
-		return self.location
+		return self.coordinates
 
-	def setLocation(self, location):
-		self.location = location
+	def setLocation(self, coordinates):
+		self.coordinates = coordinates
+
+	def hasAddress(self):
+		return self.address is not None
+	
+	def getAddress(self):
+		return self.address
+
+	def setAddress(self, address):
+		self.address = address
 
 	def hasInstant(self):
 		return self.instant is not None
@@ -50,13 +61,16 @@ class Waypoint(Obj):
 		waypoint = super(Waypoint, self).serialize(model)
 			
 		if self.hasLocation():
-			waypoint.addProperty(model.createProperty( PROPERTY.SEAS_LOCATION ), self.getLocation().serialize(model))
+			waypoint.addProperty(model.createProperty( PROPERTY.LOCATION ), self.getLocation().serialize(model))
 		
+		if self.hasAddress():
+			waypoint.addProperty(model.createProperty( PROPERTY.HASADDRESS ), self.getAddress().serialize(model))
+
 		if self.hasInstant():
-			waypoint.addProperty(model.createProperty( PROPERTY.SEAS_INSTANT ), model.createLiteral(self.getInstant().getValue()))
+			waypoint.addProperty(model.createProperty( PROPERTY.INSTANT ), model.createLiteral(self.getInstant().getValue()))
 		
 		if self.hasRoute():
-			waypoint.addProperty(model.createProperty( PROPERTY.SEAS_ROUTE ), self.getRoute().serialize(model))
+			waypoint.addProperty(model.createProperty( PROPERTY.ROUTE ), self.getRoute().serialize(model))
 		
 		return waypoint
 	
@@ -71,18 +85,24 @@ class Waypoint(Obj):
 			for statement in resource.findProperties():
 				waypoint.parse(statement)
 		
-			return waypoint	
+			return waypoint
+		
 		else:
 			statement = resource
 			predicate = str(statement.getPredicate())
 
-			# location
-			if predicate == PROPERTY.SEAS_LOCATION:
-				self.setLocation(Location().parse(statement.getResource()))
+			# coordinates
+			if predicate == PROPERTY.LOCATION:
+				self.setLocation(Coordinates().parse(statement.getResource()))
+				return
+			
+			# address
+			if predicate == PROPERTY.HASADDRESS:
+				self.setLocation(Coordinates().parse(statement.getResource()))
 				return
 			
 			# instant
-			if predicate == PROPERTY.SEAS_INSTANT:
+			if predicate == PROPERTY.INSTANT:
 				e = statement.getObject().toPython()
 				if not isinstance(e, datetime.datetime):
 					e = parser.parse(e)
@@ -90,7 +110,7 @@ class Waypoint(Obj):
 				return
 			
 			# location
-			if predicate == PROPERTY.SEAS_ROUTE:
+			if predicate == PROPERTY.ROUTE:
 				self.setRoute(Route().parse(statement.getResource()))
 				return
 			
