@@ -1,8 +1,10 @@
 from SeasObjects.common.PROPERTY import PROPERTY
 from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.rdf.Resource import Resource
+from SeasObjects.rdf.Property import Property
 from SeasObjects.model.Obj import Obj
 from SeasObjects.model.Waypoint import Waypoint
+from rdflib.namespace import RDF
 
 import traceback
 
@@ -10,7 +12,7 @@ class Waypoints(Obj):
 	
 	def __init__(self, uri = None):
 		Obj.__init__(self, uri)
-		self.setType(RESOURCE.SEAS_WAYPOINTS)
+		self.setType(RESOURCE.WAYPOINTS)
 		self.wps = []
 	
 	def hasWaypoints(self):
@@ -29,10 +31,13 @@ class Waypoints(Obj):
 		waypoints = super(Waypoints, self).serialize(model)
 		
 		if self.hasWaypoints():
-			rdfList = model.createList()
+			rdfList = model.createOrderedList()
 			rdfList.add_items(self.wps)
 			
-			waypoints.addProperty(model.createProperty( PROPERTY.SEAS_LIST ), rdfList)
+			listContainer = model.createResource()
+			listContainer.addProperty(Property(RDF.first), rdfList)
+
+			waypoints.addProperty(model.createProperty( PROPERTY.LIST ), listContainer)
 
 		return waypoints
 	
@@ -56,7 +61,7 @@ class Waypoints(Obj):
 			predicate = str(statement.getPredicate())
 
 			# waypoints
-			if predicate == PROPERTY.SEAS_LIST:
+			if predicate == PROPERTY.LIST:
 				try:
 					self.setWaypoints(statement.getResource().toList(Waypoint))
 				except:
